<?php

namespace Litecms\Manufacturer\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\Manufacturer\Http\Requests\CarManufacturerRequest;
use Litecms\Manufacturer\Interfaces\CarManufacturerRepositoryInterface;
use Litecms\Manufacturer\Models\CarManufacturer;

/**
 * Resource controller class for car_manufacturer.
 */
class CarManufacturerResourceController extends BaseController
{

    /**
     * Initialize car_manufacturer resource controller.
     *
     * @param type CarManufacturerRepositoryInterface $car_manufacturer
     *
     * @return null
     */
    public function __construct(CarManufacturerRepositoryInterface $car_manufacturer)
    {
        parent::__construct();
        $this->repository = $car_manufacturer;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\Manufacturer\Repositories\Criteria\CarManufacturerResourceCriteria::class);
    }

    /**
     * Display a list of car_manufacturer.
     *
     * @return Response
     */
    public function index(CarManufacturerRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\Manufacturer\Repositories\Presenter\CarManufacturerPresenter::class)
                ->$function();
        }

        $car_manufacturers = $this->repository->paginate();

        return $this->response->title(trans('manufacturer::car_manufacturer.names'))
            ->view('manufacturer::car_manufacturer.index', true)
            ->data(compact('car_manufacturers'))
            ->output();
    }

    /**
     * Display car_manufacturer.
     *
     * @param Request $request
     * @param Model   $car_manufacturer
     *
     * @return Response
     */
    public function show(CarManufacturerRequest $request, CarManufacturer $car_manufacturer)
    {

        if ($car_manufacturer->exists) {
            $view = 'manufacturer::car_manufacturer.show';
        } else {
            $view = 'manufacturer::car_manufacturer.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('manufacturer::car_manufacturer.name'))
            ->data(compact('car_manufacturer'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new car_manufacturer.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(CarManufacturerRequest $request)
    {

        $car_manufacturer = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('manufacturer::car_manufacturer.name')) 
            ->view('manufacturer::car_manufacturer.create', true) 
            ->data(compact('car_manufacturer'))
            ->output();
    }

    /**
     * Create new car_manufacturer.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(CarManufacturerRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $car_manufacturer                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('manufacturer::car_manufacturer.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('manufacturer/car_manufacturer/' . $car_manufacturer->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/manufacturer/car_manufacturer'))
                ->redirect();
        }

    }

    /**
     * Show car_manufacturer for editing.
     *
     * @param Request $request
     * @param Model   $car_manufacturer
     *
     * @return Response
     */
    public function edit(CarManufacturerRequest $request, CarManufacturer $car_manufacturer)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('manufacturer::car_manufacturer.name'))
            ->view('manufacturer::car_manufacturer.edit', true)
            ->data(compact('car_manufacturer'))
            ->output();
    }

    /**
     * Update the car_manufacturer.
     *
     * @param Request $request
     * @param Model   $car_manufacturer
     *
     * @return Response
     */
    public function update(CarManufacturerRequest $request, CarManufacturer $car_manufacturer)
    {
        try {
            $attributes = $request->all();

            $car_manufacturer->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('manufacturer::car_manufacturer.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('manufacturer/car_manufacturer/' . $car_manufacturer->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('manufacturer/car_manufacturer/' . $car_manufacturer->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the car_manufacturer.
     *
     * @param Model   $car_manufacturer
     *
     * @return Response
     */
    public function destroy(CarManufacturerRequest $request, CarManufacturer $car_manufacturer)
    {
        try {

            $car_manufacturer->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('manufacturer::car_manufacturer.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('manufacturer/car_manufacturer/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('manufacturer/car_manufacturer/' . $car_manufacturer->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple car_manufacturer.
     *
     * @param Model   $car_manufacturer
     *
     * @return Response
     */
    public function delete(CarManufacturerRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('manufacturer::car_manufacturer.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('manufacturer/car_manufacturer'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/manufacturer/car_manufacturer'))
                ->redirect();
        }

    }

    /**
     * Restore deleted car_manufacturers.
     *
     * @param Model   $car_manufacturer
     *
     * @return Response
     */
    public function restore(CarManufacturerRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('manufacturer::car_manufacturer.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/manufacturer/car_manufacturer'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/manufacturer/car_manufacturer/'))
                ->redirect();
        }

    }

}
